@@ -1,5 +1,5 @@
 /*****************************************************************************
- * RRDtool 1.5.6, Copyright 1997-2016 by Tobi Oetiker
+ * RRDtool 1.6.0, Copyright 1997-2016 by Tobi Oetiker
  *****************************************************************************
  * rrd_cgi.c  RRD Web Page Generator
  *****************************************************************************/
@@ -332,7 +332,7 @@ static const char *putvar(
     return varheap[i].value;
 }
 
-/* expand those RRD:* directives that can be used recursivly */
+/* expand those RRD:* directives that can be used recursively */
 static char *rrd_expand_vars(
     char *buffer)
 {
@@ -452,10 +452,12 @@ int main(
     char     *buffer;
     long      i;
     long      filter = 0;
-    struct option long_options[] = {
-        {"filter", no_argument, 0, 'f'},
-        {0, 0, 0, 0}
+    struct optparse_long longopts[] = {
+        {"filter", 'f', OPTPARSE_NONE},
+        {0},
     };
+    struct optparse options;
+    int opt;
 
 #ifdef MUST_DISABLE_SIGFPE
     signal(SIGFPE, SIG_IGN);
@@ -463,27 +465,18 @@ int main(
 #ifdef MUST_DISABLE_FPMASK
     fpsetmask(0);
 #endif
-    optind = 0;
-    opterr = 0;         /* initialize getopt */
 
     /* what do we get for cmdline arguments?
        for (i=0;i<argc;i++)
        printf("%d-'%s'\n",i,argv[i]); */
-    while (1) {
-        int       option_index = 0;
-        int       opt;
-
-        opt = getopt_long(argc, argv, "f", long_options, &option_index);
-        if (opt == EOF) {
-            break;
-        }
-
+    optparse_init(&options, argc, argv);
+    while ((opt = optparse_long(&options,longopts,NULL)) != -1) {
         switch (opt) {
         case 'f':
             filter = 1;
             break;
         case '?':
-            printf("unknown commandline option '%s'\n", argv[optind - 1]);
+            printf("%s\n", options.errmsg);
             return -1;
         }
     }
@@ -496,15 +489,15 @@ int main(
     /* make sure we have one extra argument, 
        if there are others, we do not care Apache gives several */
 
-    /* if ( (optind != argc-2 
+    /* if ( (options.optind != options.argc-2 
        && strstr( getenv("SERVER_SOFTWARE"),"Apache/2") != NULL) 
-       && optind != argc-1) { */
+       && options.optind != options.argc-1) { */
 
-    if (optind >= argc) {
+    if (options.optind >= options.argc) {
         fprintf(stderr, "ERROR: expected a filename\n");
         exit(1);
     } else {
-        readfile(argv[optind], &buffer, 1);
+        readfile(options.argv[options.optind], &buffer, 1);
     }
 
     if (rrd_test_error()) {
@@ -521,7 +514,7 @@ int main(
 #endif
 
 
-    /* expand rrd directives in buffer recursivly */
+    /* expand rrd directives in buffer recursivley */
     for (i = 0; buffer[i]; i++) {
         if (buffer[i] != '<')
             continue;
@@ -787,7 +780,7 @@ char     *includefile(
             return buffer;
         }
     } else {
-        return stralloc("[ERROR: No Inclue file defined]");
+        return stralloc("[ERROR: No Include file defined]");
     }
 }
 
@@ -1023,7 +1016,7 @@ char     *printtimenow(
     return stralloc("[ERROR: not enough arguments for RRD::TIME::NOW]");
 }
 
-/* Scan buffer until an unescaped '>' arives.
+/* Scan buffer until an unescaped '>' arrives.
  * Update argument array with arguments found.
  * Return end cursor where parsing stopped, or NULL in case of failure.
  *
@@ -1509,7 +1502,7 @@ s_var   **rrdcgiReadVariables(
                                result[i]->name, result[i]->value);
                 }
                 i++;
-            } else {    /* There is already such a name, suppose a mutiple field */
+            } else {    /* There is already such a name, suppose a multiple field */
                 cp = ++esp;
                 len = strlen(result[k]->value) + (ip - esp) + 2;
                 if ((sptr = (char *) calloc(len, sizeof(char))) == NULL)
