@@ -2,7 +2,7 @@
 #define RRD_TOOL_H_3853987DDF7E4709A5B5849E5A6204F4
 
 /*****************************************************************************
- * RRDtool 1.5.6, Copyright 1997-2016 by Tobi Oetiker
+ * RRDtool 1.6.0, Copyright 1997-2016 by Tobi Oetiker
  *****************************************************************************
  * rrd_tool.h   Common Header File
  *****************************************************************************/
@@ -46,13 +46,7 @@ extern    "C" {
 #endif
 
 /* local include files -- need to be after the system ones */
-#ifdef HAVE_GETOPT_LONG
-#define _GNU_SOURCE
-#include <getopt.h>
-#else
-#include "rrd_getopt.h"
-#endif
-
+#include "optparse.h"
 #include "rrd_format.h"
 
 #ifndef max
