@@ -1,5 +1,5 @@
 /****************************************************************************
- * RRDtool 1.5.6, Copyright 1997-2016 by Tobi Oetiker
+ * RRDtool 1.6.0, Copyright 1997-2016 by Tobi Oetiker
  ****************************************************************************
  * rrd_xport.c  export RRD data
  ****************************************************************************/
@@ -12,7 +12,6 @@
 #include "rrd_xport.h"
 #include "unused.h"
 #include "rrd_client.h"
-#include "optparse.h"
 
 #if defined(_WIN32) && !defined(__CYGWIN__) && !defined(__CYGWIN32__)
 #include <io.h>
@@ -83,7 +82,8 @@ int rrd_xport(
         {"maxrows",'m', OPTPARSE_REQUIRED},
         {"step",   261, OPTPARSE_REQUIRED},
         {"enumds", 262, OPTPARSE_NONE},
-        {"json",   263, OPTPARSE_NONE},    /* these are handled in the frontend ... */
+        {"json",   263, OPTPARSE_NONE},
+        {"showtime", 't', OPTPARSE_NONE},
         {"daemon", 'd', OPTPARSE_REQUIRED},
         {0}
     };
@@ -95,7 +95,8 @@ int rrd_xport(
 
     int enumds=0;
     int json=0;
-
+    int showtime=0;
+    
     int opt;
     while ((opt = optparse_long(&options,longopts,NULL)) != -1){
 
@@ -109,6 +110,9 @@ int rrd_xport(
         case 263:
   	    json=1;
             break;
+        case 't':
+  	    showtime=1;
+            break;
         case 's':
             if ((parsetime_error = rrd_parsetime(options.optarg, &start_tv))) {
                 rrd_set_error("start time: %s", parsetime_error);
@@ -147,7 +151,7 @@ int rrd_xport(
         }
 
         case '?':
-            rrd_set_error("%s: %s", argv[0], options.errmsg);
+            rrd_set_error("%s", options.errmsg);
             return -1;
         }
     }
@@ -172,7 +176,7 @@ int rrd_xport(
     im.end = end_tmp;
     im.step = max((long) im.step, (im.end - im.start) / im.xsize);
 
-    rrd_graph_script(argc, argv, &im, options.optind);
+    rrd_graph_script(options.argc, options.argv, &im, options.optind);
     if (rrd_test_error()) {
         im_free(&im);
         return -1;
@@ -198,6 +202,7 @@ int rrd_xport(
     if (!xsize) {
       int flags=0;
       if (json) { flags|=1; }
+      if (showtime) { flags|=2; }
       if (enumds) { flags|=4; }
       stringbuffer_t buffer={0,0,NULL,stdout};
       rrd_xport_format_xmljson(flags,&buffer,&im,
@@ -448,7 +453,7 @@ int rrd_graph_xport(image_desc_t *im) {
     free(legend_v);
     /* free data */
     free(data);
-    /* free the bufer */
+    /* free the buffer */
     if (buffer.data) {free(buffer.data);}
     /* close the file */
     if (buffer.file) {fclose(buffer.file);}
@@ -471,7 +476,7 @@ int rrd_graph_xport(image_desc_t *im) {
 }
 
 int addToBuffer(stringbuffer_t * sb,char* data,size_t len) {
-  /* if len <= 0  we assume a string and calculate the length ourself */
+  /* if len <= 0  we assume a string and calculate the length ourselves */
   if (len<=0) { len=strlen(data); }
   /* if we have got a file, then take the shortcut */
   if (sb->file) {
@@ -880,7 +885,7 @@ int rrd_xport_format_addprints(int flags,stringbuffer_t *buffer,image_desc_t *im
       /* PRINT and GPRINT can now print VDEF generated values.
        * There's no need to do any calculations on them as these
        * calculations were already made.
-       * we do not support the depreciated version here
+       * we do not support the deprecated version here
        */
       printval=DNAN;
       /* decide to which buffer we print to*/
